@@ -1,11 +1,12 @@
-# $Id: Env.pm,v 1.1 2002/09/03 11:38:33 comdog Exp $
+# $Id: Env.pm,v 1.2 2002/10/09 05:57:49 comdog Exp $
 package Test::Env;
 use strict;
 
 use base qw(Exporter);
-use vars qw(@EXPORT);
+use vars qw(@EXPORT $VERSION);
 
-@EXPORT = qw(env_ok);
+@EXPORT  = qw(env_ok);
+$VERSION = 0.06;
 
 use Test::Builder;
 
